@@ -2,9 +2,8 @@ package MooseX::Types::CreditCard;
 use 5.008;
 use strict;
 use warnings;
-use namespace::autoclean;
 
-our $VERSION = '0.002000'; # VERSION
+our $VERSION = '0.002003'; # VERSION
 
 use MooseX::Types -declare => [ qw(
 	CreditCard
@@ -13,18 +12,18 @@ use MooseX::Types -declare => [ qw(
 	CardExpiration
 ) ];
 
+use Module::Runtime                        qw( use_module      );
 use MooseX::Types::Moose                   qw( Str Int HashRef );
 use MooseX::Types::Common::String 0.001005 qw( NumericCode     );
 use MooseX::Types::DateTime ();
 
-use Class::Load 0.20 qw( load_class );
 
 subtype CardNumber,
 	as NumericCode,
 	where {
 		length($_) <= 20
 		&& length $_ >= 12
-		&& load_class('Business::CreditCard')
+		&& use_module('Business::CreditCard')
 		&& Business::CreditCard::validate($_)
 	},
 	message {'"'. $_ . '" is not a valid credit card number' };
@@ -48,7 +47,7 @@ subtype CardExpiration,
 		my ( $month, $year ) = ( $_->month, $_->year );
 
 		my $comparitor
-			= load_class('DateTime')
+			= use_module('DateTime')
 			->last_day_of_month( month => $month, year => $year )
 			;
 
@@ -63,7 +62,7 @@ subtype CreditCard,
 	as CardNumber,
 	where {
 		our @CARP_NOT = qw( Moose::Meta::TypeConstraint );
-		load_class('Carp');
+		use_module('Carp');
 		Carp::carp 'DEPRECATED: use CardNumber instead of CreditCard Type';
 		1;
 	}, # just for backcompat
@@ -87,7 +86,7 @@ coerce CreditCard, from Str,
 
 coerce CardExpiration, from HashRef,
 	via {
-		return load_class('DateTime')->last_day_of_month( %{ $_ } );
+		return use_module('DateTime')->last_day_of_month( %{ $_ } );
 	};
 
 1;
@@ -98,13 +97,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MooseX::Types::CreditCard - Moose Types related to Credit Cards
 
 =head1 VERSION
 
-version 0.002000
+version 0.002003
 
 =head1 SYNOPSIS
 
@@ -169,7 +170,7 @@ A Credit L<Card Security Code|http://wikipedia.org/wiki/Card_security_code> is
 a 3 or 4 digit number. This is also called CSC, CVV, CVC, and CID, depending
 on the issuing vendor.
 
-=head2 CardExpiration
+=head2 head2 CardExpiration
 
 B<Base Type:> C<DateTime>
 
@@ -180,6 +181,16 @@ stored in the object.
 Coerce allows you to create the L<DateTime> object from a C<HashRef> by passing
 the keys C<month> and C<year>.
 
+=head1 ACKNOWLEDGEMENTS
+
+=over
+
+=item * L<hostgator.com>
+
+For funding initial development
+
+=back
+
 =head1 SEE ALSO
 
 =over
@@ -193,7 +204,7 @@ the keys C<month> and C<year>.
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website
-https://github.com/xenoterracide/MooseX-Types-CreditCard/issues
+https://github.com/xenoterracide/moosex-types-creditcard/issues
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
@@ -205,7 +216,7 @@ Caleb Cushing <xenoterracide@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by HostGator.com.
+This software is Copyright (c) 2014 by Caleb Cushing.
 
 This is free software, licensed under:
 
